@@ -26,18 +26,30 @@ class Bot:
 	Attributes
     ----------	
 	
-	http_token : str
+	token : str
 		The token for the bot.
 	intents : int
 		The priveliged intents.
 	command_prefix : str
 		The command prefix for the bot.	
+	http : HTTPClient
+	    The http client that sends requests to discord.
 	"""
 	def __init__(self, command_prefix : str = None, intents : int = 0, token : str = None):
-		self.http = HTTPClient(token)
+		self.http = HTTPClient(self)
 		self.token = token
 		self.intents = intents
 		self.command_prefix = command_prefix
+		
+	
+	def close(self):
+		"""
+		:function:
+			
+		The function to close the websocket connection.
+		"""
+		
+		Gateway().close()
 
 		
 	def run(self):
@@ -48,5 +60,6 @@ class Bot:
 		"""
 		try:
 			payload = Gateway().connect(str(self.token), self.intents)
+			payload
 		except Exception as e:
-			raise InvokeError(e)																									
\ No newline at end of file
+			raise InvokeError(e)															
\ No newline at end of file
