@@ -28,6 +28,13 @@ class Gateway:
 		
 		t = Template('{"op": 2,"d": {"token": "$token","intents": $intents, "properties": {"$os": "linux","$browser": "discord.api","$device": "discord.api"}},"s": null,"t": null}')
 		return t.substitute(token=str(token), intents=intents, os="$os", browser="$browser", device="$device")
+	
+	async def close(self):
+		"""
+		The |async| function to close the connection.
+		"""
+				
+		await self.ws.close()
 		
 	async def _connect(self, _token : str, _intents : int):
 		"""
@@ -42,13 +49,13 @@ class Gateway:
 			The intents for the bot.
 		"""		
 		try:
-			ws = await aiohttp.ClientSession().ws_connect("wss://gateway.discord.gg/?v=6&encoding=json")			
+			self.ws = await aiohttp.ClientSession().ws_connect("wss://gateway.discord.gg/?v=6&encoding=json")			
 			heartbeat = '{"op": 1,"d": 251}'
 			p = self.identify_json(_token, _intents)
 			h = json.loads(heartbeat)
 			h_json = json.dumps(h)
-			await ws.send_str(h_json)
-			await ws.send_str(p)
+			await self.ws.send_str(h_json)
+			await self.ws.send_str(p)
 		except Exception as e:
 			print(e)
 		
